above property
Optional widget rendered just above the portrait controls panel, inside the same SafeArea — guaranteed not to be covered by the panel.
Implementation
final Widget? above;
Optional widget rendered just above the portrait controls panel, inside the same SafeArea — guaranteed not to be covered by the panel.
final Widget? above;